chordtools.yield_groups_of_chords_in_sequence
=============================================

.. autofunction:: abjad.tools.chordtools.yield_groups_of_chords_in_sequence.yield_groups_of_chords_in_sequence
